<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Delegate\Handlers\ContactEvent;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\User\Models\User;
use EventPortal\Enums\InertiaMethod;

Form::make('contact.create')
    ->addHandler(new ContactEvent())
    ->addFields(function (User $user) {
        return [
            Section::make('')->fields([
                Text::make('First name')
                    ->rules(['required'])
                    ->placeholder('Jane')
                    ->value(optional($user)->first_name),
                Text::make('Last name')
                    ->rules(['required'])
                    ->placeholder('Doe')
                    ->value(optional($user)->last_name),
                Text::make('Email')
                    ->rules(['required', 'email'])
                    ->placeholder('janedoe@example.com')
                    ->value(optional($user)->email),
                Text::make('Phone')
                    ->placeholder('01234 56789'),
                Text::make('Subject')
                    ->rules(['required'])
                    ->placeholder('Please enter a subject'),
                TextArea::make('Message')
                    ->rules(['required'])
                    ->placeholder('Please enter your message'),
            ]),
        ];
    })
    ->addPrimaryAction(function (Event $event) {
        return Button::make('Send enquiry')
            ->method(InertiaMethod::POST())
            ->route('contact.store', ['event' => $event->slug]);
    });
