<?php

namespace EventPortal\Domain\Form;

use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Form\Models\Form as FormModel;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use Illuminate\Support\Arr;

class FormRegistry
{
    /** @var array<string> */
    private $forms = [];

    public function make(string $formName): Form
    {
        if (Arr::has($this->forms, $formName)) {
            return $this->forms[$formName];
        }

        $this->forms[$formName] = new Form($formName);

        return $this->forms[$formName];
    }

    public function makeFromDatabase(FormModel $form, ?FormStep $formStep = null): Form
    {
        $step = $formStep ?? $form->steps->first();

        if (Arr::has($this->forms, $step->name)) {
            return $this->forms[$step->name];
        }

        $step->loadMissing([
            'sections.questions.options',
            'sections.questions.validations',
        ]);

        $this->forms[$step->name] = new Form($step->name);
        $this->forms[$step->name]->fromDatabase();
        $this->forms[$step->name]->addFields(static function () use ($step): array {
            return $step->sections->map(function (FormStepSection $section): Section {
                return Section::make($section->name)->fields(
                    $section->questions->map(function (Question $question) {
                        return $question->asComponent();
                    })->all()
                );
            })->all();
        });

        return $this->forms[$step->name];
    }
}
